#ifndef COLUMBUSDIALOG_H
#define COLUMBUSDIALOG_H

#include "ApplicationController.h"
#include <rx/widgets/Maemo5Dialog.h>

class ColumbusDialogPrivate;

class ColumbusDialog : public Maemo5Dialog
{
    Q_OBJECT
    Q_PROPERTY(ApplicationController* controller READ controller WRITE setController)

public:
    explicit ColumbusDialog (QWidget *parent = 0);
            ~ColumbusDialog ();

    ApplicationController* controller() const;

public slots:
    virtual void setController(ApplicationController *controller);

private:
    ColumbusDialogPrivate *d;
};

#endif // COLUMBUSDIALOG_H
